@@ -1,4 +1,4 @@
-from clusterone.config import Config
+from clusterone.persistance.session import Session
 
 import functools
 
@@ -9,14 +9,14 @@ def authenticate():
         @functools.wraps(f)
         def wrapper(*args, **kwargs):
             try:
-                config = args[0].config
+                session = args[0].config
             except:
-                config = Config()
-                config.__init__()
-                config.load()
+                session = Session()
+                session.__init__()
+                session.load()
 
-            username = config.get('username')
-            token = config.get('token')
+            username = session.get('username')
+            token = session.get('token')
             if username == '' or token == '':
                 print("You are not logged in yet. Use 'just login'.")
                 return
