@@ -19,6 +19,14 @@ class DuplicateProjectName(ClusteroneException):
         return "Duplicate project name. Project names must be unique"
 
 
+class UnsupportedSource(ClusteroneException):
+    def __str__(self):
+        return "Unsupported Dataset Source."
+
+class BucketNameNotAvaliable(ClusteroneException):
+    def __str__(self):
+        return "The requested bucket name is not available. The bucket namespace is shared by all users of the system"
+
 class DuplicateDatasetName(ClusteroneException):
     def __str__(self):
         return "Duplicate dataset name. Dataset names must be unique"
