@@ -3,27 +3,38 @@ from collections import OrderedDict
 from functools import reduce
 
 import click
-from click import Choice
-from click.exceptions import BadParameter
+from click.exceptions import BadParameter, MissingParameter
 
 from clusterone import client, authenticate
 from clusterone.client_exceptions import FailedCommitReference, NoProjectCommits
-from clusterone.config import Config
-from clusterone.utilities import random_job_name, path_to_project, time_limit_to_minutes, path_to_dataset, LazyChoice
+from clusterone.utilities import random_job_name, path_to_project, time_limit_to_minutes, path_to_dataset, Choice, append_to_docstring
 
 
+#TODO: Move this to custom types
 def validate_name(context, parameters, value):
     if not regexp.match("^[a-zA-Z0-9_-]+$", value):
         raise BadParameter("Should only contain alphanumeric characters, \"_\", or \"-\".")
 
     return value
 
+
 def validate_time_limit(context, parameters, value):
     try:
-        return time_limit_to_minutes(value)
+       return time_limit_to_minutes(value)
     except ValueError:
         raise BadParameter("Please conform to [hours]h[minutes]m format, ex. \"20h12m\".")
 
+
+def validate_module_arguments(context, parameters, raw_value):
+    arguments = [argument.lstrip('-') for argument in raw_value[::2]]
+    values = raw_value[1::2]
+
+    if len(arguments) != len(values):
+        raise MissingParameter("", param_type="one or more value for custom arguments")
+
+    return {argument: value for argument, value in zip(arguments, values)}
+
+
 def combine_options(options):
     """
     Generates a single decorator out of list of options decorator
@@ -33,10 +44,22 @@ def combine_options(options):
         return reduce(lambda decoratee, option_decorator: option_decorator(decoratee), reversed(options), function)
     return wrapper
 
+
 job_base_options = combine_options([
-    click.command(),
+    # This is used to process user defined arguments
+    # See to learn more: http://click.pocoo.org/6/advanced/#forwarding-unknown-options
+    click.command(context_settings=dict(
+        ignore_unknown_options=True,
+    )),
+    click.argument('custom-arguments', nargs=-1, callback=validate_module_arguments),
+    # Documenting the above behavior to the user
+    append_to_docstring('\n\nCustom arguments can be passed via "--myarg myvalue" syntax.'),
+
+    # Common options for implementation
     click.pass_obj,
     authenticate(),
+
+    # Business logic common options
     click.option(
         '--name',
         default=random_job_name(),
@@ -67,7 +90,6 @@ job_base_options = combine_options([
     click.option(
         '--package-path',
         # The project root is represented by API as None
-        # TODO: Test if this works
         help='Path to module, default is the project root.',
         ),
     click.option(
@@ -78,7 +100,7 @@ job_base_options = combine_options([
         ),
     click.option(
         '--framework',
-        type=LazyChoice(client.framework_slugs),
+        type=Choice(client.framework_slugs),
         default="tensorflow-1.3.0",
         help='Framework to be used. Default: tensorflow',
         ),
@@ -106,12 +128,15 @@ job_base_options = combine_options([
         '--description',
         default="",
         help='Job description [optional].'
-        )
+        ),
     ])
 
-def base(context, kwargs):
 
-    #config, client = context.config, context.client
+#TODO: Python2.7 compliance legacy - add * after last positional argument
+def base(context, kwargs, module_arguments=None):
+    """
+    Common option processing login for all job types
+    """
 
     project = path_to_project(kwargs['project_path'], context=context)
     project_id = project['id']
@@ -132,13 +157,20 @@ def base(context, kwargs):
     #TODO: OMG MOCK THIS IN OTHER TESTS
     datasets_list = []
 
-    try:
-        for raw_dataset_string in kwargs['datasets'].split(','):
-            dataset_path, dataset_commit = raw_dataset_string.split(':')
-            dataset = path_to_dataset(dataset_path, context=context)
-            datasets_list.append(OrderedDict({'dataset': dataset['id'], 'git_commit_hash': dataset_commit}))
-    except ValueError as exception:
-        pass
+    if kwargs['datasets'] != '':
+        try:
+            for raw_dataset_string in kwargs['datasets'].split(','):
+                try:
+                    dataset_path, dataset_commit = raw_dataset_string.split(':')
+                except ValueError as exception:
+                    dataset_path = raw_dataset_string
+                    #TODO: Allow NULL on the API
+                    dataset_commit = "dummy"
+
+                dataset = path_to_dataset(dataset_path, context=context)
+                datasets_list.append(OrderedDict({'dataset': dataset['id'], 'git_commit_hash': dataset_commit}))
+        except ValueError as exception:
+            pass
 
     # Caution, this isn't sustainable behavior if we add more Python versions!!!
     python_version = '2.7' if kwargs['python_version'] in ['2.7','2'] else '3.5'
@@ -163,6 +195,7 @@ def base(context, kwargs):
             "datasets_set": datasets_list,
             "code": project_id,
             "code_commit": commit,
+            "module_arguments": module_arguments,
             "framework":
             {
                 "slug": framework_slug
@@ -175,4 +208,3 @@ def base(context, kwargs):
             "description": kwargs['description'],
         }
     }
-
