@@ -3,10 +3,10 @@ import time
 from clusterone.client_exceptions import RemoteAquisitionFailure
 
 
-def aquire_remote(project_name, config, client):
+def aquire_remote(project_name, session, client):
 
-    username = config.get('username')
-    retry_count, retry_interval = config.retry_count, config.retry_interval
+    username = session.get('username')
+    retry_count, retry_interval = session.retry_count, session.retry_interval
 
     for _ in range(retry_count):
         time.sleep(retry_interval)
@@ -22,8 +22,8 @@ def aquire_remote(project_name, config, client):
 
 def main(context, name, description):
 
-    client, config = context.client, context.config
+    client, session = context.client, context.session
 
     project_name = client.create_project(name, description)
-    project_url = aquire_remote(project_name, client=client, config=config)
+    project_url = aquire_remote(project_name, client=client, session=session)
     return project_url
