@@ -11,8 +11,8 @@ HEADER_BASE = [
     'Status',
     'Project',
     'Module',
-    'Package-path',
-    'Datasets',
+    #'Package-path',
+    #'Datasets',
     'Python version',
     'Package manager',
     'Requirements',
@@ -43,8 +43,8 @@ def extract_data_from_job(job):
         job['status'],
         job['repository_name'],
         job['parameters']['module'],
-        job['parameters']['package_path'],
-        displayable_data(job['parameters']['datasets']),
+        #job['parameters']['package_path'],
+        #displayable_data(job['parameters']['datasets']),
         job['parameters']['python_version'],
         job['parameters']['package_manager'],
         job['parameters']['requirements'],
