@@ -22,7 +22,7 @@ def command(context, dataset_path, repo_path):
     Links existing Clusterone dataset with a local git repository
     """
 
-    client, config, cwd = context.client, context.config, context.cwd
+    client, session, cwd = context.client, context.session, context.cwd
 
     # since context cannot be referenced in the deault paramters
     repository_path = repo_path if repo_path is not None else cwd
@@ -31,7 +31,7 @@ def command(context, dataset_path, repo_path):
 
     if not len(path_tokens) == 2:
         if len(path_tokens) == 1:
-            path_tokens = [config.get("username")] + path_tokens
+            path_tokens = [session.get("username")] + path_tokens
         else:
             raise BadParameter(param_hint="--dataset-path", message="Please provide a valid dataset-path. The format is \"username/dataset\".")
 
