@@ -11,7 +11,7 @@ def command(context):
     Log out from Clusterone
     """
 
-    context.config.delete()
+    context.session.delete()
     #TODO: Do a request to API to logout
     #TODO: Test this
     #TODO: Pylint tests
