@@ -1,7 +1,7 @@
 from click.testing import CliRunner
 
 from clusterone import ClusteroneClient
-from clusterone.config import Config
+from clusterone.persistance.session import Session
 from clusterone.clusterone_cli import cli
 
 from clusterone.commands.logout import cmd
@@ -13,10 +13,10 @@ def test_local_session_deletion(mocker):
     """
 
     mocker.patch.object(ClusteroneClient, '__init__', autospec=True, return_value=None)
-    mocker.patch.object(Config, 'delete', autospec=True, return_value=None)
+    mocker.patch.object(Session, 'delete', autospec=True, return_value=None)
 
     cmd.is_latest_version = mocker.Mock(return_value=False)
 
     CliRunner().invoke(cli, ['logout'])
 
-    assert Config.delete.called
+    assert Session.delete.called
