@@ -2,7 +2,7 @@
 
 import click
 from click import launch
-from clusterone.clusterone_client import MATRIX_URL
+from clusterone import client
 
 
 @click.command()
@@ -13,4 +13,4 @@ def command(context):
     """
 
     #TODO: What if operating in headless mode? What does happens then?
-    launch(MATRIX_URL)
+    launch(client.matrix_url)
