@@ -13,14 +13,14 @@ from clusterone.utilities import path_to_job_id
 @click.option(
     '--job-id',
     '-i',
-    help='Pause the job with the job with specified job id.')
+    help='Stop the job with the job with specified job id.')
 @click.option(
     '--job-path',
     '-p',
-    help='Pause the job with matching path. A job path is “username/project/job-path.')
+    help='Stop the job with matching path. A job path is “username/project/job-path.')
 def command(context, job_path, job_id):
     """
-    Pause a job, either by name or id
+    Stop a job, either by name or id
     """
 
     client = context.client
