@@ -17,10 +17,12 @@ from subprocess import run, PIPE
 from time import sleep
 import requests
 import json
+import os
 
 from clusterone import ClusteroneClient
 
 INVOCATION_PREFIX = "python3 clusterone/clusterone_cli.py"
+URL = "https://clusterone.com/api/"
 
 def just(command):
     just_command = "{} {}".format(INVOCATION_PREFIX, command)
@@ -46,7 +48,7 @@ def get_outputs(token):
 
     job_id = job_data_parsed[job_data_parsed.index("None/clusterone-test-bob") + 2]
 
-    url = "https://clusterone.com/api/jobs/{}/files/".format(job_id)
+    url = "{}jobs/{}/files/".format(URL, job_id)
     header = {"Authorization": "JWT {}".format(token)}
     response = requests.request("GET", url, headers=header)
     output_files = json.loads(response.text)[0]['contents']
@@ -62,23 +64,32 @@ def main():
     print("Generated pass: {}".format(password))
 
     exit_code = 0
-    client = ClusteroneClient(username=username)
+    client = ClusteroneClient(username=username, api_url=URL)
 
     try:
-        call("rm -f /home/allgreed/.config/clusterone/config.json")
+        call("rm -f /home/allgreed/.config/clusterone/session.json")
+
+        call(just("config endpoint {}".format(URL)))
+        print("Using endpoint {}".format(URL))
 
         response = client.client_action(['register', 'create'], params={
             'username': username,
             'email': '{}@example.com'.format(salt),
             'password': password,
         }, validate=True)
+        #TODO: Do some kind of check here
+        #TODO: Move this to the CLI
         print("Registration complete")
 
         login_output = call(just("login --username {} --password {}").format(username, password)).decode("utf-8")
         assert "successful" in login_output
         print("Login completed")
 
-        token = json.loads((call("cat /home/allgreed/.config/clusterone/config.json")).decode("utf-8"))['token']
+        sleep(1)
+
+        with open("/home/allgreed/.config/clusterone/session.json") as cokolwiek:
+            token = json.loads("".join(cokolwiek.readlines()))['token']
+
         print("Token aquired: {}...".format(token[0:10]))
 
         job_state = str(call(just("get jobs")), 'utf-8')
@@ -130,7 +141,7 @@ def main():
     call(just("stop -p clusterone-test-mnist/clusterone-test-bob"), asserted=False)
     subprocess.call("echo 'y' | {} rm job clusterone-test-mnist/clusterone-test-bob ; sleep 1".format(INVOCATION_PREFIX), shell=True)
     subprocess.call("echo 'y' | {} rm project clusterone-test-mnist ; sleep 1".format(INVOCATION_PREFIX), shell=True)
-    url = "https://clusterone.com/api/users/{}".format(username)
+    url = "{}users/{}".format(URL, username)
     header = {"Authorization": "JWT {}".format(token)}
     response = requests.request("DELETE", url, headers=header)
     call("rm -rf mnist", asserted=False)
