@@ -1,15 +1,19 @@
-"""
-blah blah blah
+""" blah blah blah
 """
 
 from clusterone.utils import render_table
 
 def main(_data, header=None):
+    """
+    ???
+    """
     #TODO: Pull the code from render_table here and refactor it, then test
-    table_data = [header]
 
-    for row in _data:
-        table_data.append(row)
+
+    # Otherwise the table would broke
+    assert len(header) == len(_data[0])
+
+    table_data = [header] + [row for row in _data]
 
     table = render_table(table_data, 36).table
     return table
